package com.javaproxy;

import java.io.IOException;
import java.io.InputStream;
import java.io.Reader;
import org.xmlpull.v1.XmlPullParserException;

/* JADX INFO: Access modifiers changed from: package-private */
/* compiled from: XmlManifestReader.java */
/* loaded from: com_javaproxy.jar:com/javaproxy/XmlResourceParser.class */
public class XmlResourceParser implements android.content.res.XmlResourceParser {
    private IntReader m_reader;
    private StringBlock m_strings;
    private int[] m_resourceIDs;
    private boolean m_decreaseDepth;
    private int m_event;
    private int m_lineNumber;
    private int m_name;
    private int m_namespaceUri;
    private int[] m_attributes;
    private int m_idAttribute;
    private int m_classAttribute;
    private int m_styleAttribute;
    private static final String E_NOT_SUPPORTED = "Method is not supported.";
    private static final int ATTRIBUTE_IX_NAMESPACE_URI = 0;
    private static final int ATTRIBUTE_IX_NAME = 1;
    private static final int ATTRIBUTE_IX_VALUE_STRING = 2;
    private static final int ATTRIBUTE_IX_VALUE_TYPE = 3;
    private static final int ATTRIBUTE_IX_VALUE_DATA = 4;
    private static final int ATTRIBUTE_LENGHT = 5;
    private static final int CHUNK_AXML_FILE = 524291;
    private static final int CHUNK_RESOURCEIDS = 524672;
    private static final int CHUNK_XML_FIRST = 1048832;
    private static final int CHUNK_XML_START_NAMESPACE = 1048832;
    private static final int CHUNK_XML_END_NAMESPACE = 1048833;
    private static final int CHUNK_XML_START_TAG = 1048834;
    private static final int CHUNK_XML_END_TAG = 1048835;
    private static final int CHUNK_XML_TEXT = 1048836;
    private static final int CHUNK_XML_LAST = 1048836;
    private boolean m_operational = false;
    private NamespaceStack m_namespaces = new NamespaceStack();

    public XmlResourceParser() {
        resetEventInfo();
    }

    public void open(InputStream stream) {
        close();
        if (stream != null) {
            this.m_reader = new IntReader(stream, false);
        }
    }

    @Override // android.content.res.XmlResourceParser, java.lang.AutoCloseable
    public void close() {
        if (!this.m_operational) {
            return;
        }
        this.m_operational = false;
        this.m_reader.close();
        this.m_reader = null;
        this.m_strings = null;
        this.m_resourceIDs = null;
        this.m_namespaces.reset();
        resetEventInfo();
    }

    public static final void readCheckType(IntReader reader, int expectedType) throws IOException {
        int type = reader.readInt();
        if (type != expectedType) {
            throw new IOException("Expected chunk of type 0x" + Integer.toHexString(expectedType) + ", read 0x" + Integer.toHexString(type) + ".");
        }
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public int next() throws XmlPullParserException, IOException {
        if (this.m_reader == null) {
            throw new XmlPullParserException("Parser is not opened.", this, null);
        }
        try {
            doNext();
            return this.m_event;
        } catch (IOException e) {
            close();
            throw e;
        }
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public int nextToken() throws XmlPullParserException, IOException {
        return next();
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public int nextTag() throws XmlPullParserException, IOException {
        int eventType = next();
        if (eventType == ATTRIBUTE_IX_VALUE_DATA && isWhitespace()) {
            eventType = next();
        }
        if (eventType != ATTRIBUTE_IX_VALUE_STRING && eventType != ATTRIBUTE_IX_VALUE_TYPE) {
            throw new XmlPullParserException("Expected start or end tag.", this, null);
        }
        return eventType;
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public String nextText() throws XmlPullParserException, IOException {
        if (getEventType() != ATTRIBUTE_IX_VALUE_STRING) {
            throw new XmlPullParserException("Parser must be on START_TAG to read next text.", this, null);
        }
        int eventType = next();
        if (eventType == ATTRIBUTE_IX_VALUE_DATA) {
            String result = getText();
            if (next() != ATTRIBUTE_IX_VALUE_TYPE) {
                throw new XmlPullParserException("Event TEXT must be immediately followed by END_TAG.", this, null);
            }
            return result;
        }
        if (eventType == ATTRIBUTE_IX_VALUE_TYPE) {
            return "";
        }
        throw new XmlPullParserException("Parser must be on START_TAG or TEXT to read text.", this, null);
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public void require(int type, String namespace, String name) throws XmlPullParserException, IOException {
        if (type != getEventType() || ((namespace != null && !namespace.equals(getNamespace())) || (name != null && !name.equals(getName())))) {
            throw new XmlPullParserException(String.valueOf(TYPES[type]) + " is expected.", this, null);
        }
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public int getDepth() {
        return this.m_namespaces.getDepth() - ATTRIBUTE_IX_NAME;
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public int getEventType() throws XmlPullParserException {
        return this.m_event;
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public int getLineNumber() {
        return this.m_lineNumber;
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public String getName() {
        if (this.m_name == -1) {
            return null;
        }
        if (this.m_event != ATTRIBUTE_IX_VALUE_STRING && this.m_event != ATTRIBUTE_IX_VALUE_TYPE) {
            return null;
        }
        return this.m_strings.getString(this.m_name);
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public String getText() {
        if (this.m_name == -1 || this.m_event != ATTRIBUTE_IX_VALUE_DATA) {
            return null;
        }
        return this.m_strings.getString(this.m_name);
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public char[] getTextCharacters(int[] holderForStartAndLength) {
        String text = getText();
        if (text == null) {
            return null;
        }
        holderForStartAndLength[ATTRIBUTE_IX_NAMESPACE_URI] = ATTRIBUTE_IX_NAMESPACE_URI;
        holderForStartAndLength[ATTRIBUTE_IX_NAME] = text.length();
        char[] chars = new char[text.length()];
        text.getChars(ATTRIBUTE_IX_NAMESPACE_URI, text.length(), chars, ATTRIBUTE_IX_NAMESPACE_URI);
        return chars;
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public String getNamespace() {
        return this.m_strings.getString(this.m_namespaceUri);
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public String getPrefix() {
        int prefix = this.m_namespaces.findPrefix(this.m_namespaceUri);
        return this.m_strings.getString(prefix);
    }

    @Override // org.xmlpull.v1.XmlPullParser, android.util.AttributeSet
    public String getPositionDescription() {
        return "XML line #" + getLineNumber();
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public int getNamespaceCount(int depth) throws XmlPullParserException {
        return this.m_namespaces.getAccumulatedCount(depth);
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public String getNamespacePrefix(int pos) throws XmlPullParserException {
        int prefix = this.m_namespaces.getPrefix(pos);
        return this.m_strings.getString(prefix);
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public String getNamespaceUri(int pos) throws XmlPullParserException {
        int uri = this.m_namespaces.getUri(pos);
        return this.m_strings.getString(uri);
    }

    @Override // android.util.AttributeSet
    public String getClassAttribute() {
        if (this.m_classAttribute == -1) {
            return null;
        }
        int offset = getAttributeOffset(this.m_classAttribute);
        int value = this.m_attributes[offset + ATTRIBUTE_IX_VALUE_STRING];
        return this.m_strings.getString(value);
    }

    @Override // android.util.AttributeSet
    public String getIdAttribute() {
        if (this.m_idAttribute == -1) {
            return null;
        }
        int offset = getAttributeOffset(this.m_idAttribute);
        int value = this.m_attributes[offset + ATTRIBUTE_IX_VALUE_STRING];
        return this.m_strings.getString(value);
    }

    @Override // android.util.AttributeSet
    public int getIdAttributeResourceValue(int defaultValue) {
        if (this.m_idAttribute == -1) {
            return defaultValue;
        }
        int offset = getAttributeOffset(this.m_idAttribute);
        int valueType = this.m_attributes[offset + ATTRIBUTE_IX_VALUE_TYPE];
        if (valueType != ATTRIBUTE_IX_NAME) {
            return defaultValue;
        }
        return this.m_attributes[offset + ATTRIBUTE_IX_VALUE_DATA];
    }

    @Override // android.util.AttributeSet
    public int getStyleAttribute() {
        if (this.m_styleAttribute == -1) {
            return ATTRIBUTE_IX_NAMESPACE_URI;
        }
        int offset = getAttributeOffset(this.m_styleAttribute);
        return this.m_attributes[offset + ATTRIBUTE_IX_VALUE_DATA];
    }

    @Override // org.xmlpull.v1.XmlPullParser, android.util.AttributeSet
    public int getAttributeCount() {
        if (this.m_event != ATTRIBUTE_IX_VALUE_STRING) {
            return -1;
        }
        return this.m_attributes.length / ATTRIBUTE_LENGHT;
    }

    @Override // android.content.res.XmlResourceParser, org.xmlpull.v1.XmlPullParser, android.util.AttributeSet
    public String getAttributeNamespace(int index) {
        int offset = getAttributeOffset(index);
        int namespace = this.m_attributes[offset + ATTRIBUTE_IX_NAMESPACE_URI];
        if (namespace == -1) {
            return "";
        }
        return this.m_strings.getString(namespace);
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public String getAttributePrefix(int index) {
        int offset = getAttributeOffset(index);
        int uri = this.m_attributes[offset + ATTRIBUTE_IX_NAMESPACE_URI];
        int prefix = this.m_namespaces.findPrefix(uri);
        if (prefix == -1) {
            return "";
        }
        return this.m_strings.getString(prefix);
    }

    @Override // org.xmlpull.v1.XmlPullParser, android.util.AttributeSet
    public String getAttributeName(int index) {
        int offset = getAttributeOffset(index);
        int name = this.m_attributes[offset + ATTRIBUTE_IX_NAME];
        if (name == -1) {
            return "";
        }
        return this.m_strings.getString(name);
    }

    @Override // android.util.AttributeSet
    public int getAttributeNameResource(int index) {
        int offset = getAttributeOffset(index);
        int name = this.m_attributes[offset + ATTRIBUTE_IX_NAME];
        if (this.m_resourceIDs == null || name < 0 || name >= this.m_resourceIDs.length) {
            return ATTRIBUTE_IX_NAMESPACE_URI;
        }
        return this.m_resourceIDs[name];
    }

    public int getAttributeValueType(int index) {
        int offset = getAttributeOffset(index);
        return this.m_attributes[offset + ATTRIBUTE_IX_VALUE_TYPE];
    }

    public int getAttributeValueData(int index) {
        int offset = getAttributeOffset(index);
        return this.m_attributes[offset + ATTRIBUTE_IX_VALUE_DATA];
    }

    @Override // org.xmlpull.v1.XmlPullParser, android.util.AttributeSet
    public String getAttributeValue(int index) {
        int offset = getAttributeOffset(index);
        int valueType = this.m_attributes[offset + ATTRIBUTE_IX_VALUE_TYPE];
        if (valueType == ATTRIBUTE_IX_VALUE_TYPE) {
            int valueString = this.m_attributes[offset + ATTRIBUTE_IX_VALUE_STRING];
            return this.m_strings.getString(valueString);
        }
        int i = this.m_attributes[offset + ATTRIBUTE_IX_VALUE_DATA];
        return "";
    }

    @Override // android.util.AttributeSet
    public boolean getAttributeBooleanValue(int index, boolean defaultValue) {
        return getAttributeIntValue(index, defaultValue ? ATTRIBUTE_IX_NAME : ATTRIBUTE_IX_NAMESPACE_URI) != 0;
    }

    @Override // android.util.AttributeSet
    public float getAttributeFloatValue(int index, float defaultValue) {
        int offset = getAttributeOffset(index);
        int valueType = this.m_attributes[offset + ATTRIBUTE_IX_VALUE_TYPE];
        if (valueType == ATTRIBUTE_IX_VALUE_DATA) {
            int valueData = this.m_attributes[offset + ATTRIBUTE_IX_VALUE_DATA];
            return Float.intBitsToFloat(valueData);
        }
        return defaultValue;
    }

    @Override // android.util.AttributeSet
    public int getAttributeIntValue(int index, int defaultValue) {
        int offset = getAttributeOffset(index);
        int valueType = this.m_attributes[offset + ATTRIBUTE_IX_VALUE_TYPE];
        if (valueType >= 16 && valueType <= 31) {
            return this.m_attributes[offset + ATTRIBUTE_IX_VALUE_DATA];
        }
        return defaultValue;
    }

    @Override // android.util.AttributeSet
    public int getAttributeUnsignedIntValue(int index, int defaultValue) {
        return getAttributeIntValue(index, defaultValue);
    }

    @Override // android.util.AttributeSet
    public int getAttributeResourceValue(int index, int defaultValue) {
        int offset = getAttributeOffset(index);
        int valueType = this.m_attributes[offset + ATTRIBUTE_IX_VALUE_TYPE];
        if (valueType == ATTRIBUTE_IX_NAME) {
            return this.m_attributes[offset + ATTRIBUTE_IX_VALUE_DATA];
        }
        return defaultValue;
    }

    @Override // org.xmlpull.v1.XmlPullParser, android.util.AttributeSet
    public String getAttributeValue(String namespace, String attribute) {
        int index = findAttribute(namespace, attribute);
        if (index == -1) {
            return null;
        }
        return getAttributeValue(index);
    }

    @Override // android.util.AttributeSet
    public boolean getAttributeBooleanValue(String namespace, String attribute, boolean defaultValue) {
        int index = findAttribute(namespace, attribute);
        if (index == -1) {
            return defaultValue;
        }
        return getAttributeBooleanValue(index, defaultValue);
    }

    @Override // android.util.AttributeSet
    public float getAttributeFloatValue(String namespace, String attribute, float defaultValue) {
        int index = findAttribute(namespace, attribute);
        if (index == -1) {
            return defaultValue;
        }
        return getAttributeFloatValue(index, defaultValue);
    }

    @Override // android.util.AttributeSet
    public int getAttributeIntValue(String namespace, String attribute, int defaultValue) {
        int index = findAttribute(namespace, attribute);
        if (index == -1) {
            return defaultValue;
        }
        return getAttributeIntValue(index, defaultValue);
    }

    @Override // android.util.AttributeSet
    public int getAttributeUnsignedIntValue(String namespace, String attribute, int defaultValue) {
        int index = findAttribute(namespace, attribute);
        if (index == -1) {
            return defaultValue;
        }
        return getAttributeUnsignedIntValue(index, defaultValue);
    }

    @Override // android.util.AttributeSet
    public int getAttributeResourceValue(String namespace, String attribute, int defaultValue) {
        int index = findAttribute(namespace, attribute);
        if (index == -1) {
            return defaultValue;
        }
        return getAttributeResourceValue(index, defaultValue);
    }

    @Override // android.util.AttributeSet
    public int getAttributeListValue(int index, String[] options, int defaultValue) {
        return ATTRIBUTE_IX_NAMESPACE_URI;
    }

    @Override // android.util.AttributeSet
    public int getAttributeListValue(String namespace, String attribute, String[] options, int defaultValue) {
        return ATTRIBUTE_IX_NAMESPACE_URI;
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public String getAttributeType(int index) {
        return "CDATA";
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public boolean isAttributeDefault(int index) {
        return false;
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public void setInput(InputStream stream, String inputEncoding) throws XmlPullParserException {
        throw new XmlPullParserException(E_NOT_SUPPORTED);
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public void setInput(Reader reader) throws XmlPullParserException {
        throw new XmlPullParserException(E_NOT_SUPPORTED);
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public String getInputEncoding() {
        return null;
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public int getColumnNumber() {
        return -1;
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public boolean isEmptyElementTag() throws XmlPullParserException {
        return false;
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public boolean isWhitespace() throws XmlPullParserException {
        return false;
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public void defineEntityReplacementText(String entityName, String replacementText) throws XmlPullParserException {
        throw new XmlPullParserException(E_NOT_SUPPORTED);
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public String getNamespace(String prefix) {
        throw new RuntimeException(E_NOT_SUPPORTED);
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public Object getProperty(String name) {
        return null;
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public void setProperty(String name, Object value) throws XmlPullParserException {
        throw new XmlPullParserException(E_NOT_SUPPORTED);
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public boolean getFeature(String feature) {
        return false;
    }

    @Override // org.xmlpull.v1.XmlPullParser
    public void setFeature(String name, boolean value) throws XmlPullParserException {
        throw new XmlPullParserException(E_NOT_SUPPORTED);
    }

    final StringBlock getStrings() {
        return this.m_strings;
    }

    private final int getAttributeOffset(int index) {
        if (this.m_event != ATTRIBUTE_IX_VALUE_STRING) {
            throw new IndexOutOfBoundsException("Current event is not START_TAG.");
        }
        int offset = index * ATTRIBUTE_LENGHT;
        if (offset >= this.m_attributes.length) {
            throw new IndexOutOfBoundsException("Invalid attribute index (" + index + ").");
        }
        return offset;
    }

    private final int findAttribute(String namespace, String attribute) {
        int name;
        if (this.m_strings == null || attribute == null || (name = this.m_strings.find(attribute)) == -1) {
            return -1;
        }
        int uri = namespace != null ? this.m_strings.find(namespace) : -1;
        for (int o = ATTRIBUTE_IX_NAMESPACE_URI; o != this.m_attributes.length; o += ATTRIBUTE_IX_NAME) {
            if (name == this.m_attributes[o + ATTRIBUTE_IX_NAME] && (uri == -1 || uri == this.m_attributes[o + ATTRIBUTE_IX_NAMESPACE_URI])) {
                return o / ATTRIBUTE_LENGHT;
            }
        }
        return -1;
    }

    private final void resetEventInfo() {
        this.m_event = -1;
        this.m_lineNumber = -1;
        this.m_name = -1;
        this.m_namespaceUri = -1;
        this.m_attributes = null;
        this.m_idAttribute = -1;
        this.m_classAttribute = -1;
        this.m_styleAttribute = -1;
    }

    /* JADX WARN: Code restructure failed: missing block: B:77:0x00fd, code lost:
    
        throw new java.io.IOException("Invalid chunk type (" + r8 + ").");
     */
    /* JADX WARN: Code restructure failed: missing block: B:88:0x00bf, code lost:
    
        throw new java.io.IOException("Invalid resource ids size (" + r0 + ").");
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    private final void doNext() throws java.io.IOException {
        /*
            Method dump skipped, instructions count: 620
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.javaproxy.XmlResourceParser.doNext():void");
    }
}
